# -*- coding: utf-8 -*-

# Copyright 2011-2012 Richard Dymond (rjdymond@gmail.com)
#
# This file is part of SkoolKit.
#
# SkoolKit is free software: you can redistribute it and/or modify it under the
# terms of the GNU General Public License as published by the Free Software
# Foundation, either version 3 of the License, or (at your option) any later
# version.
#
# SkoolKit is distributed in the hope that it will be useful, but WITHOUT ANY
# WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
# A PARTICULAR PURPOSE. See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along with
# SkoolKit. If not, see <http://www.gnu.org/licenses/>.

import sys

VERSION = '3.1.1'
ENCODING = 'utf-8'
PY3 = sys.version_info >= (3,)

def error(msg):
    sys.stderr.write('ERROR: {0}\n'.format(msg))
    sys.exit(1)

def warn(msg):
    sys.stderr.write('WARNING: {0}\n'.format(msg))

def usage(msg):
    sys.stderr.write('Usage: {0}\n'.format(msg))
    sys.exit(1)

def info(msg):
    sys.stderr.write('{0}\n'.format(msg))

def version():
    sys.stdout.write('SkoolKit {0}\n'.format(VERSION))
    sys.exit(0)

def write(text):
    sys.stdout.write(text)
    sys.stdout.flush()

def write_line(text):
    sys.stdout.write('{0}\n'.format(text))

def write_text(text):
    sys.stdout.write(text)

def parse_int(num_str, default=None):
    try:
        if num_str.startswith('$'):
            return int(num_str[1:], 16)
        return int(num_str)
    except ValueError:
        return default

def get_chr(code):
    return chr(code) if PY3 else unichr(code).encode(ENCODING)

def get_class(name):
    if '.' not in name:
        error("Invalid class name: '{0}'".format(name))
    elements = name.split('.')
    mod_name = '.'.join(elements[:-1])
    cls_name = elements[-1]
    try:
        m = __import__(mod_name, globals(), locals(), [cls_name])
    except ImportError as e:
        error("Failed to import class {0}: {1}".format(name, e.args[0]))
    try:
        return getattr(m, cls_name)
    except AttributeError:
        error("No class named '{0}' in module '{1}'".format(cls_name, mod_name))
