# -*- coding: utf-8 -*-
import unittest

from skoolkittest import SkoolKitTestCase
from skoolkit import skool2ctl

ELEMENTS = 'btdrmsc'

USAGE = """Usage: skool2ctl.py [options] FILE

  Convert a skool file into a control file, written to standard output. FILE
  may be a regular file, or '-' for standard input.

Options:
  -w X  Write only these elements, where X is one or more of:
          b = block types and addresses
          t = block titles
          d = block descriptions
          r = registers
          m = mid-block comments and block end comments
          s = sub-block types and addresses
          c = instruction-level comments
  -h    Write addresses in hexadecimal format
  -a    Do not write ASM directives"""

class Skool2CtlTest(SkoolKitTestCase):
    def test_no_arguments(self):
        output, error = self.run_skool2ctl(err_lines=True)
        self.assert_output_equal(error, USAGE.split('\n'))

    def test_invalid_arguments(self):
        for args in ('-h', '-x test.skool'):
            output, error = self.run_skool2ctl(args, err_lines=True)
            self.assert_output_equal(error, USAGE.split('\n'))

    def test_w(self):
        skoolfile = 'test.skool'
        for w in ('b', 't', 'd', 'r', 'm', 's', 'c', 'btd', ELEMENTS):
            infile, elements, write_hex, write_asm_dirs = skool2ctl.parse_args(('-w', w, skoolfile))
            self.assertEqual(infile, skoolfile)
            self.assertEqual(elements, w)
            self.assertFalse(write_hex)
            self.assertTrue(write_asm_dirs)

    def test_h(self):
        skoolfile = 'test.skool'
        infile, elements, write_hex, write_asm_dirs = skool2ctl.parse_args(('-h', skoolfile))
        self.assertEqual(infile, skoolfile)
        self.assertEqual(elements, ELEMENTS)
        self.assertTrue(write_hex)
        self.assertTrue(write_asm_dirs)

    def test_a(self):
        skoolfile = 'test.skool'
        infile, elements, write_hex, write_asm_dirs = skool2ctl.parse_args(('-a', skoolfile))
        self.assertEqual(infile, skoolfile)
        self.assertEqual(elements, ELEMENTS)
        self.assertFalse(write_hex)
        self.assertFalse(write_asm_dirs)

if __name__ == '__main__':
    unittest.main()
