# -*- coding: utf-8 -*-
import unittest

from skoolkittest import SkoolKitTestCase
from skoolkit import skool2sft

USAGE = """Usage: skool2sft.py [options] FILE

  Convert a skool file into a skool file template, written to standard output.
  FILE may be a regular file, or '-' for standard input.

Options:
  -h  Write addresses in hexadecimal format"""

class Skool2SftTest(SkoolKitTestCase):
    def test_no_arguments(self):
        output, error = self.run_skool2sft(err_lines=True)
        self.assert_output_equal(error, USAGE.split('\n'))

    def test_invalid_arguments(self):
        for args in ('-h', '-x test.skool'):
            output, error = self.run_skool2sft(args, err_lines=True)
            self.assert_output_equal(error, USAGE.split('\n'))

    def test_no_options(self):
        skoolfile = 'test.skool'
        infile, write_hex = skool2sft.parse_args((skoolfile,))
        self.assertEqual(infile, skoolfile)
        self.assertFalse(write_hex)

    def test_h(self):
        skoolfile = 'test.skool'
        infile, write_hex = skool2sft.parse_args(('-h', skoolfile))
        self.assertEqual(infile, skoolfile)
        self.assertTrue(write_hex)

if __name__ == '__main__':
    unittest.main()
